# Xorfilter: Rust xor filter implementation

Abstract from [original authors](https://github.com/FastFilter/xorfilter): Bloom filters are used to quickly check whether an element is part of a set. Xor filters are a faster and more concise alternative to Bloom filters. They are also smaller than cuckoo filters.

## API

```rust
use Xorfilter;

fn main() {

    // create filter // default Xor8
    let mut xor_filter = Xorfilter::Xorfilter::new();
    
    // create keys
    // uses helper function below
    let keys = create_keys(10009);

    // create copy to test contain function
    let testkeys = keys.clone();

    // populate keys
    xor_filter.populate(keys);

    // test contain keys
    for key in &testkeys {
        println!("{}", xor_filter.contains(*key));
    }

}

fn create_keys(n: usize) -> Vec<u64> {
   let mut keys: Vec<u64> = Vec::with_capacity(n);

    for i in 0..n {
        keys.push((i*120) as u64);
    }
    keys
}
```
## Status

Currently only supports Xor8

## Reference

[Xor Filters: Faster and Smaller Than Bloom and Cuckoo
Filters](https://arxiv.org/abs/1912.08258), Journal of Experimental
Algorithmics.

